use tempfile::tempdir;

use crate::output::message_info;
use std::{error::Error, fs::create_dir, path::PathBuf};

pub fn setup_workdir(path: Option<String>) -> Result<String, Box<dyn Error>> {
    let path = match path {
        Some(res) => {
            message_info(&format!("trying to create a dir: {}", res));
            match create_dir(res.clone()) {
                Ok(_) => PathBuf::from(res),
                Err(err) => {
                    let _msg = format!("couldn't create dir {}", res);
                    return Err(Box::from(err));
                }
            }
        }

        None => {
            message_info("trying to create a temporary dir");
            // I'm using into_path to prevent the dir from being removed
            tempdir()?.into_path()
        }
    };
    Ok(path.into_os_string().into_string().unwrap())
}

#[cfg(test)]
mod tests {
    use std::{error::Error, fs::remove_dir_all, path::Path};

    use tempfile::tempdir;

    use crate::workdir::setup_workdir;

    #[test]
    fn test_temporary_dir() -> Result<(), Box<dyn Error>> {
        let wd = setup_workdir(None)?;
        let result = Path::new(&wd).exists();
        assert!(result);
        remove_dir_all(wd)?;
        Ok(())
    }

    #[test]
    fn test_specified_dir() -> Result<(), Box<dyn Error>> {
        let dir = tempdir()?;
        let path = dir.path().join("test").to_str().unwrap().to_string();
        let wd = setup_workdir(Some(path.clone()))?;
        let result = Path::new(&wd).exists();
        assert!(result);
        assert!(setup_workdir(Some(path)).is_err());
        remove_dir_all(dir)?;
        Ok(())
    }
}
